@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2016, 2017 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2016-2019 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -19,6 +19,8 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 #include "config.h"
 
+#include <iostream>
+
 // Octaves non-static verror functions: The elder all set error_state,
 // the newer, present from the time on at which error started to throw
 // an exception, all throw, too.
@@ -26,9 +28,9 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 // call verror, for _linking_ also against Octave versions who have no
 // verror() with these arguments
 #ifdef HAVE_OCTAVE_VERROR_ARG_EXC
-void c_verror (octave_execution_exception&, const char *, ...);
+void c_verror (OCTAVE__EXECUTION_EXCEPTION&, const char *, ...);
 #else
-void c_verror (const octave_execution_exception&, const char *, ...);
+void c_verror (const OCTAVE__EXECUTION_EXCEPTION&, const char *, ...);
 #endif
 
 void _p_error (const char *fmt, ...);
@@ -37,7 +39,7 @@ void _p_error (const char *fmt, ...);
 // both if Octave uses exceptions for errors and if it still uses
 // error_state. In the latter case return 'retval'.
 #ifdef HAVE_OCTAVE_ERROR_STATE
-  // can throw octave_execution_exception despite of this
+  // can throw OCTAVE__EXECUTION_EXCEPTION despite of this
   #define CHECK_ERROR(code, retval, ...)      \
     try \
       { \
@@ -50,7 +52,7 @@ void _p_error (const char *fmt, ...);
             return retval; \
           } \
       } \
-    catch (octave_execution_exception& e) \
+    catch (OCTAVE__EXECUTION_EXCEPTION& e) \
       { \
         c_verror (e, __VA_ARGS__); \
       }
@@ -60,9 +62,9 @@ void _p_error (const char *fmt, ...);
       { \
         code ; \
       } \
-    catch (octave_execution_exception& e) \
+    catch (OCTAVE__EXECUTION_EXCEPTION& e) \
       { \
-        verror (e, __VA_ARGS__); \
+        c_verror (e, __VA_ARGS__); \
       }
 #endif
 
@@ -70,7 +72,7 @@ void _p_error (const char *fmt, ...);
 // Octave doesn't throw exceptions for errors but still uses
 // error_state.
 #ifdef HAVE_OCTAVE_ERROR_STATE
-  // can throw octave_execution_exception despite of this
+  // can throw OCTAVE__EXECUTION_EXCEPTION despite of this
   #define CHECK_ERROR_EXIT1(code, ...) \
     try \
       { \
@@ -83,7 +85,7 @@ void _p_error (const char *fmt, ...);
             exit (1); \
           } \
       } \
-    catch (octave_execution_exception&) \
+    catch (OCTAVE__EXECUTION_EXCEPTION&) \
       { \
         _p_error (__VA_ARGS__); \
  \
@@ -95,7 +97,7 @@ void _p_error (const char *fmt, ...);
       { \
         code ; \
       } \
-    catch (octave_execution_exception&) \
+    catch (OCTAVE__EXECUTION_EXCEPTION&) \
       { \
         _p_error (__VA_ARGS__); \
  \
@@ -107,7 +109,7 @@ void _p_error (const char *fmt, ...);
 // Octave uses exceptions for errors and if it still uses
 // error_state. In the latter case reset error_state to 0.
 #ifdef HAVE_OCTAVE_ERROR_STATE
-  // can throw octave_execution_exception despite of this
+  // can throw OCTAVE__EXECUTION_EXCEPTION despite of this
   #define SET_ERR(code, err) \
     err = false; \
  \
@@ -120,7 +122,7 @@ void _p_error (const char *fmt, ...);
             err = true; \
           } \
       } \
-    catch (octave_execution_exception&) \
+    catch (OCTAVE__EXECUTION_EXCEPTION&) \
       { \
         err = true; \
       }
@@ -132,7 +134,7 @@ void _p_error (const char *fmt, ...);
       { \
         code ; \
       } \
-    catch (octave_execution_exception&) \
+    catch (OCTAVE__EXECUTION_EXCEPTION&) \
       { \
         err = true; \
       }
